@@ -21,6 +21,9 @@ foreach my $report (@{setting('reports')}) {
     category => ($report->{category} || 'My Reports'),
     ($report->{hidden} ? (hidden => true) : ()),
     provides_csv => true,
+    api_endpoint => true,
+    bind_params  => $report->{bind_params},
+    api_parameters => $report->{api_parameters},
   });
 
   get "/ajax/content/report/$r" => require_login sub {
@@ -76,16 +79,14 @@ foreach my $report (@{setting('reports')}) {
                 is_custom_report => true,
                 column_options => \%column_config,
                 headings => [map {$column_config{$_}->{displayname}} @column_order],
-                columns => [@column_order] },
-              { layout => undef };
+                columns => [@column_order] };
       }
       else {
           header( 'Content-Type' => 'text/comma-separated-values' );
           template 'ajax/report/generic_report_csv.tt',
               { results => \@results,
                 headings => [map {$column_config{$_}->{displayname}} @column_order],
-                columns => [@column_order] },
-              { layout => undef };
+                columns => [@column_order] };
       }
   };
 }
