@@ -7,7 +7,33 @@ use Dancer::Plugin::Auth::Extensible;
 use App::Netdisco::Web::Plugin;
 use App::Netdisco::Util::Web 'sql_match';
 
-register_search_tab( { tag => 'port', label => 'Port', provides_csv => 1 } );
+register_search_tab({
+    tag => 'port',
+    label => 'Port',
+    provides_csv => 1,
+    api_endpoint => 1,
+    api_parameters => [
+      q => {
+        description => 'Port name or VLAN or MAC address',
+        required => 1,
+      },
+      partial => {
+        description => 'Search for a partial match on parameter "q"',
+        type => 'boolean',
+        default => 'true',
+      },
+      uplink => {
+        description => 'Include uplinks in results',
+        type => 'boolean',
+        default => 'false',
+      },
+      ethernet => {
+        description => 'Only Ethernet type interfaces in results',
+        type => 'boolean',
+        default => 'true',
+      },
+    ],
+});
 
 # device ports with a description (er, name) matching
 get '/ajax/content/search/port' => require_login sub {
@@ -67,13 +93,11 @@ get '/ajax/content/search/port' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json( \@results );
-        template 'ajax/search/port.tt', { results => $json },
-            { layout => undef };
+        template 'ajax/search/port.tt', { results => $json };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
-        template 'ajax/search/port_csv.tt', { results => \@results },
-            { layout => undef };
+        template 'ajax/search/port_csv.tt', { results => \@results };
     }
 };
 
